Class: Librevox::Listener::Base::CommandDelegate

Inherits:
Object
  • Object
show all
Includes:
Commands
Defined in:
lib/librevox/listener/base.rb

Overview

In some cases there are both applications and commands with the same name, e.g. fifo. But we can't have two fifo-methods, so we include commands in CommandDelegate, and expose all commands through the api method, which wraps a CommandDelegate instance.

Instance Method Summary collapse

Methods included from Commands

#fsctl, #hash, #hupall, #originate, #status, #uuid_bridge, #uuid_park

Constructor Details

#initialize(listener) ⇒ CommandDelegate

Returns a new instance of CommandDelegate.



32
33
34
# File 'lib/librevox/listener/base.rb', line 32

def initialize(listener)
  @listener = listener
end

Instance Method Details

#command(*args) ⇒ Object



36
37
38
# File 'lib/librevox/listener/base.rb', line 36

def command(*args)
  @listener.send_message(super(*args))
end